@@ -1,10 +1,10 @@
 package Net::DNS::Packet;
 
 #
-# $Id: Packet.pm 1172 2014-02-28 09:39:14Z willem $
+# $Id: Packet.pm 1204 2014-05-20 20:52:47Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1172 $)[1];
+$VERSION = (qw$LastChangedRevision: 1204 $)[1];
 
 
 =head1 NAME
@@ -31,14 +31,19 @@ use strict;
 use integer;
 use Carp;
 
-use base qw(Exporter);
-use vars qw(@EXPORT_OK);
-@EXPORT_OK = qw(dn_expand);
+use constant UDPSZ => 512;
 
 require Net::DNS::Header;
 require Net::DNS::Question;
 require Net::DNS::RR;
 
+use constant DNSSEC17 => eval {
+	require Net::DNS::RR::DS;	## Net::DNS::SEC 0.17 compatible
+	$Net::DNS::RR::DS::VERSION < 1179;
+} || 0;
+
+my @dummy_header = (header => {}) if DNSSEC17;
+
 
 =head1 METHODS
 
@@ -67,7 +72,7 @@ sub new {
 		answer	   => [],
 		authority  => [],
 		additional => [],
-		header	   => {}	## Compatibility with Net::DNS::SEC
+		@dummy_header		## Net::DNS::SEC 0.17 compatible
 		}, $class;
 
 	$self->{question} = [Net::DNS::Question->new(@_)] if scalar @_;
@@ -131,7 +136,7 @@ sub decode {
 			authority  => [],
 			additional => [],
 			answersize => length $$data,
-			header	   => {}## Compatibility with Net::DNS::SEC
+			@dummy_header	## Net::DNS::SEC 0.17 compatible
 			}, $class;
 
 		# question/zone section
@@ -721,7 +726,7 @@ sub sign_tsig {
 		Net::DNS::RR::TSIG->create(@_);
 	} || croak "$@\nTSIG: unable to sign packet";
 
-	CORE::push( @{$self->{additional}}, $tsig );
+	$self->push( 'additional', $tsig );
 	return $tsig;
 }
 
@@ -801,7 +806,7 @@ sub sign_sig0 {
 		}
 	} || croak "$@\nSIG0: Net::DNS::SEC not available";
 
-	CORE::push( @{$self->{additional}}, $sig0 );
+	$self->push( 'additional', $sig0 );
 	return $sig0;
 }
 
@@ -840,7 +845,7 @@ sub truncate {
 	my $self=shift;
 	my $max_len=shift;
 	my $debug=0;
-	$max_len=$max_len>512?$max_len:512;
+	$max_len=$max_len>UDPSZ?$max_len:UDPSZ;
 
 	print "Truncating to $max_len\n" if $debug;
 
@@ -891,16 +896,15 @@ sub truncate {
 sub dump {				## print internal data structure
 	require Data::Dumper;
 	local $Data::Dumper::Maxdepth = 6;
-	local $Data::Dumper::Sortkeys = $Data::Dumper::Sortkeys = 1;
-	return Data::Dumper::Dumper(shift) if defined wantarray;
-	print Data::Dumper::Dumper(shift);
+	local $Data::Dumper::Sortkeys = 1;
+	print Data::Dumper::Dumper(@_);
 }
 
 
 sub sigrr {				## obtain packet signature RR
 	my $self = shift;
 
-	my ($sig) = reverse @{$self->{additional}};
+	my ($sig) = reverse $self->additional;
 	return undef unless $sig;
 	return $sig if $sig->type eq 'TSIG';
 	return $sig if $sig->type eq 'SIG';
