@@ -1,10 +1,10 @@
 package Net::DNS::Resolver;
 
 #
-# $Id: Resolver.pm 1020 2012-10-04 09:11:25Z willem $
+# $Id: Resolver.pm 1202 2014-05-19 08:34:16Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1020 $)[1];
+$VERSION = (qw$LastChangedRevision: 1202 $)[1];
 
 =head1 NAME
 
@@ -21,28 +21,22 @@ BEGIN {
 	for ($^O) {				## Perl OS identifier
 
 		/cygwin/ && do {
-			eval { require Net::DNS::Resolver::MSWin32; };
-
-			unless ($@) {
+			if ( eval "require Net::DNS::Resolver::MSWin32;" ) {
 				@ISA = qw(Net::DNS::Resolver::MSWin32);
 				last;
 			}
 		};
 
-
-		eval "require Net::DNS::Resolver::$_;";
-
-		unless ($@) {
+		if ( eval "require Net::DNS::Resolver::$_;" ) {
 			@ISA = ("Net::DNS::Resolver::$_");
-		} else {
-			require Net::DNS::Resolver::UNIX;
-			@ISA = qw(Net::DNS::Resolver::UNIX);
+			last;
 		}
+
+		require Net::DNS::Resolver::UNIX;
+		@ISA = qw(Net::DNS::Resolver::UNIX);
 	}
 }
 
-__PACKAGE__->init();
-
 
 1;
 
@@ -269,28 +263,28 @@ Use C<< $packet->header->ancount >> or C<< $packet->answer >> to find out
 if there were any records in the answer section.  Returns C<undef> if there
 was an error.
 
+
 =head2 axfr
 
     @zone = $res->axfr;
     @zone = $res->axfr('example.com');
-    @zone = $res->axfr('passwd.example.com', 'HS');
+    @zone = $res->axfr('example.com', 'HS');
 
 Performs a zone transfer from the first nameserver listed in C<nameservers>.
-If the zone is omitted, it defaults to the first zone listed in the resolver's
+If the zone is omitted, it defaults to the first zone listed in the resolver
 search list.  If the class is omitted, it defaults to IN.
 
-Returns a list of C<Net::DNS::RR> objects, or C<undef> if the zone
+Returns a list of C<Net::DNS::RR> objects, or empty list if the zone
 transfer failed.
 
 The redundant SOA record that terminates the zone transfer is not
 returned to the caller.
 
-See also L</axfr_start> and L</axfr_next>.
+Here's an example that uses a timeout and TSIG verification:
 
-Here's an example that uses a timeout:
-
-    $res->tcp_timeout(10);
-    my @zone = $res->axfr('example.com');
+    $res->tcp_timeout( 10 );
+    $res->tsig( 'Khmac-sha1.example.+161+24053.private' );
+    my @zone = $res->axfr( 'example.com' );
 
     if (@zone) {
         foreach my $rr (@zone) {
@@ -300,38 +294,6 @@ Here's an example that uses a timeout:
         print 'Zone transfer failed: ', $res->errorstring, "\n";
     }
 
-=head2 axfr_start
-
-    $res->axfr_start;
-    $res->axfr_start('example.com');
-    $res->axfr_start('example.com', 'HS');
-
-Starts a zone transfer from the first nameserver listed in C<nameservers>.
-If the zone is omitted, it defaults to the first zone listed in the resolver's
-search list.  If the class is omitted, it defaults to IN.
-
-B<IMPORTANT>:
-
-This method currently returns the C<IO::Socket::INET> object that will
-be used for reading, or C<undef> on error.  DO NOT DEPEND ON C<axfr_start()>
-returning a socket object.  THIS MIGHT CHANGE in future releases.
-
-Use C<axfr_next> to read the zone records one at a time.
-
-=head2 axfr_next
-
-    $res->axfr_start('example.com');
-
-    while (my $rr = $res->axfr_next) {
-	    $rr->print;
-    }
-
-Reads records from a zone transfer one at a time.
-
-Returns C<undef> at the end of the zone transfer.  The redundant
-SOA record that terminates the zone transfer is not returned.
-
-See also L</axfr>.
 
 =head2 nameservers
 
@@ -430,11 +392,19 @@ $res->bgisready >> or C<IO::Select> to find out if the socket is ready
 before reading it.
 
 bgsend does not support persistent sockets.
-bgsend does not support the usevc option (TCP).
+
+B<BEWARE>:
+bgsend does not support the usevc option (TCP) and operates on UDP only;
+Answers may not fit in an UDP packet and might be truncated. Truncated 
+packets will B<not> be retried over TCP automatically and should be handled
+by the caller.
 
 =head2 bgread
 
     $packet = $res->bgread($socket);
+    if ($packet->header->tc) { 
+    	# Retry over TCP (blocking).
+    }
     undef $socket;
 
 Reads the answer from a background query (see L</bgsend>).  The argument
@@ -451,6 +421,9 @@ The programmer should close or destroy the socket object after reading it.
         # do some other processing
     }
     $packet = $res->bgread($socket);
+    if ($packet->header->tc) { 
+    	# Retry over TCP (blocking).
+    }
     $socket = undef;
 
 Determines whether a socket is ready for reading.  The argument is
@@ -458,23 +431,27 @@ an C<IO::Socket> object returned by C<< $res->bgsend >>.
 
 Returns true if the socket is ready, false if not.
 
+
 =head2 tsig
 
-    my $tsig = $res->tsig;
+    $tsig = $res->tsig;
+    $res->tsig( $tsig );
 
-    $res->tsig(Net::DNS::RR->new("$key_name TSIG $key"));
+    $res->tsig( 'Khmac-sha1.example.+161+24053.private' );
 
-    $tsig = Net::DNS::RR->new("$key_name TSIG $key");
-    $tsig->fudge(60);
-    $res->tsig($tsig);
+    $res->tsig( 'Khmac-sha1.example.+161+24053.key' );
 
-    $res->tsig($key_name, $key);
+    $res->tsig( 'Khmac-sha1.example.+161+24053.key',
+		fudge => 60
+		);
 
-    $res->tsig(0);
+    $res->tsig( $key_name, $key );
+
+    $res->tsig( undef );
 
 Get or set the TSIG record used to automatically sign outgoing
-queries and updates.  Call with an argument of 0 or '' to turn off
-automatic signing.
+queries and updates.  Call with an undefined argument, 0 or ''
+to turn off automatic signing.
 
 The default resolver behavior is not to sign any packets.  You must
 call this method to set the key if you'd like the resolver to sign
@@ -485,6 +462,7 @@ and C<Net::DNS::Update> manual pages for examples.  TSIG records
 in manually-signed packets take precedence over those that the
 resolver would add automatically.
 
+
 =head2 retrans
 
     print 'retrans interval: ', $res->retrans, "\n";
@@ -624,8 +602,8 @@ When set to true the answer and additional section of queries from
 secured zones will contain DNSKEY, NSEC and RRSIG records.
 
 Setting calling the dnssec method with a non-zero value will set the
-UDP packet size to the default value of 2048. If that is to small or
-to big for your environment you should call the udppacketsize()
+UDP packet size to the default value of 2048. If that is too small or
+too big for your environment you should call the udppacketsize()
 method immediately after.
 
    $res->dnssec(1);    # turns on DNSSEC and sets udp packetsize to 2048
@@ -666,11 +644,10 @@ to 1.
     print "udppacketsize: ", $res->udppacketsize, "\n";
     $res->udppacketsize(2048);
 
-udppacketsize will set or get the packet size. If set to a value greater than
-Net::DNS::PACKETSZ() an EDNS extension will be added indicating support for MTU path
-recovery.
+udppacketsize will set or get the packet size. If set to a value
+greater than the default DNS packet size, an EDNS extension will be
+added indicating support for UDP fragment reassembly.
 
-Default udppacketsize is Net::DNS::PACKETSZ() (512)
 
 =head1 CUSTOMIZING
 
